# Weather-Notifier
Desktop Notification tool  to show the current weather of the user's 
location.
<br><br>
**Installation/setup from source**

1. Clone the repository.
2. Run `sudo python setup.py install`
3. Run 'weathernotifier' on the terminal
<br><br>

**Requirements**
* requests==2.18.2
* pyowm
* notify2
* reverse_geocoder
<br><br>

**Screenshots**
![screenshot](https://user-images.githubusercontent.com/17358196/37515866-3b2f470e-2932-11e8-9ce8-e0d73abb6f54.png)





